@@ -6,7 +6,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "aprcl.h"
@@ -14,6 +14,6 @@
 void
 unity_zp_set_zero(unity_zp f)
 {
-    fmpz_mod_poly_zero(f->poly);
+    fmpz_mod_poly_zero(f->poly, f->ctx);
 }
 
