@@ -6,7 +6,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "aprcl.h"
@@ -16,7 +16,10 @@ unity_zpq_scalar_mul_fmpz(unity_zpq f, const unity_zpq g, const fmpz_t s)
 {
     slong i;
 
+    FLINT_ASSERT(fmpz_equal(fmpz_mod_ctx_modulus(f->ctx),
+                            fmpz_mod_ctx_modulus(g->ctx)));
+
     for (i = 0; i < f->p; i++)
-        fmpz_mod_poly_scalar_mul_fmpz(f->polys[i], g->polys[i], s);
+        fmpz_mod_poly_scalar_mul_fmpz(f->polys[i], g->polys[i], s, f->ctx);
 }
 
