@@ -6,7 +6,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "arith.h"
@@ -34,7 +34,7 @@ arith_bell_number_nmod_vec_series(mp_ptr res, slong n, nmod_t mod)
     }
     tmp[0] = UWORD(0);
 
-    _nmod_poly_exp_series(res, tmp, n, mod);
+    _nmod_poly_exp_series(res, tmp, n, n, mod);
 
     /* Multiply by factorials */
     c = UWORD(1);
