@@ -7,7 +7,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "d_mat.h"
@@ -30,7 +30,7 @@ d_mat_mul_classical(d_mat_t C, const d_mat_t A, const d_mat_t B)
         d_mat_t t;
         d_mat_init(t, ar, bc);
         d_mat_mul_classical(t, A, B);
-        d_mat_swap(C, t);
+        d_mat_swap_entrywise(C, t);
         d_mat_clear(t);
         return;
     }
