@@ -6,7 +6,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpq.h"
@@ -17,6 +17,13 @@ _fmpq_randtest(fmpz_t num, fmpz_t den, flint_rand_t state, flint_bitcnt_t bits)
     mp_limb_t x = n_randlimb(state);
 
     fmpz_randtest(num, state, bits);
+
+    if (bits == 1)
+    {
+        fmpz_one(den);
+        return;
+    }
+
     fmpz_randtest_not_zero(den, state, bits);
 
     switch (x % 16)
