@@ -6,7 +6,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpq_mat.h"
@@ -28,7 +28,7 @@ fmpq_mat_gso(fmpq_mat_t B, const fmpq_mat_t A)
         fmpq_mat_t t;
         fmpq_mat_init(t, B->r, B->c);
         fmpq_mat_gso(t, A);
-        fmpq_mat_swap(B, t);
+        fmpq_mat_swap_entrywise(B, t);
         fmpq_mat_clear(t);
         return;
     }
