@@ -6,7 +6,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <gmp.h>
@@ -31,7 +31,7 @@ void _fmpq_poly_scalar_mul_ui(fmpz * rpoly, fmpz_t rden,
     fmpz_init(gcd);
     fmpz_set_ui(gcd, c);
     fmpz_gcd(gcd, gcd, den);
-    if (*gcd == WORD(1))
+    if (fmpz_is_one(gcd))
     {
         _fmpz_vec_scalar_mul_ui(rpoly, poly, len, c);
         fmpz_set(rden, den);
