@@ -6,7 +6,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <gmp.h>
@@ -22,8 +22,6 @@
 #define DOUBLE_MIN COEFF_MIN
 #endif
 
-extern double __gmpn_get_d(mp_limb_t *, size_t, size_t, long);
-
 double
 fmpz_get_d(const fmpz_t f)
 {
@@ -40,12 +38,12 @@ fmpz_get_d(const fmpz_t f)
         if (c > 0)
         {
             d = c;
-            return __gmpn_get_d(&d, 1, 1, 0);
+            return flint_mpn_get_d(&d, 1, 1, 0);
         }
         else
         {
             d = -c;
-            return __gmpn_get_d(&d, 1, -1, 0);
+            return flint_mpn_get_d(&d, 1, -1, 0);
         }
     }
     else
