@@ -8,7 +8,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <stdio.h>
@@ -61,7 +61,7 @@ main(void)
         if (!result)
         {
             flint_printf("FAIL:\n");
-            gmp_printf("n = %wu, m = %wu, e = %Zd, f = %Zd, g = %Zd\n",
+            gmp_printf("n = %Mu, m = %Mu, e = %Zd, f = %Zd, g = %Zd\n",
                 n, m, e, f, g);
             abort();
         }
@@ -105,7 +105,7 @@ main(void)
         if (!result)
         {
             flint_printf("FAIL:\n");
-            gmp_printf("d = %Zd, n = %wu, m = %wu, f = %Zd, g = %Zd\n",
+            gmp_printf("d = %Zd, n = %Mu, m = %Mu, f = %Zd, g = %Zd\n",
                 d, n, m, f, g);
             abort();
         }
