@@ -7,7 +7,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <stdio.h>
@@ -18,7 +18,7 @@
 #include "fmpz.h"
 
 /* Composite strong pseudoprimes from
-   http://oeis.org/A014233 and https://doi.org/10.1090/mcom/3134 */
+   https://oeis.org/A014233 and https://doi.org/10.1090/mcom/3134 */
 static const char * composites[] = {
     "2047",
     "1373653",
