@@ -7,7 +7,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <stdio.h>
@@ -57,7 +57,7 @@ main(void)
         if (!result)
         {
             flint_printf("FAIL:\n");
-            gmp_printf("d = %Zd, e = %Zd, f = %Zd, x = %wu, y = %wu\n",
+            gmp_printf("d = %Zd, e = %Zd, f = %Zd, x = %Mu, y = %Mu\n",
                 d, e, f, x, y);
             abort();
         }
@@ -99,7 +99,7 @@ main(void)
         if (!result)
         {
             flint_printf("FAIL:\n");
-            gmp_printf("d = %Zd, e = %Zd, f = %Zd, x = %wu, y = %wu\n",
+            gmp_printf("d = %Zd, e = %Zd, f = %Zd, x = %Mu, y = %Mu\n",
                 d, e, f, x, y);
             abort();
         }
