@@ -6,9 +6,14 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
+/* try to get fdopen declared */
+#if defined __STRICT_ANSI__
+#undef __STRICT_ANSI__
+#endif
+
 #include <sys/types.h>
 #if (!defined (__WIN32) || defined(__CYGWIN__)) && !defined(_MSC_VER) 
 #include <unistd.h>
@@ -22,13 +27,6 @@
 
 #if (!defined (__WIN32) || defined(__CYGWIN__)) && !defined(_MSC_VER)
 
-/*
-    The function fdopen is declared in stdio.h.  It is POSIX.1 compliant, 
-    but not ANSI compliant.  The following line enables compilation with 
-    the "-ansi" flag.
- */
-extern FILE * fdopen(int fildes, const char *mode);
-
 int main(void)
 {
     int i, j, n = 10000, result;
