@@ -6,11 +6,11 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpz_lll.h"
-#if HAVE_FENV
+#if FLINT_USES_FENV
 #include <fenv.h>
 #endif
 
@@ -18,7 +18,7 @@ int
 fmpz_lll_is_reduced_d_with_removal(const fmpz_mat_t B, const fmpz_lll_t fl,
                                    const fmpz_t gs_B, int newd)
 {
-#if HAVE_FENV
+#if FLINT_USES_FENV
     if (fl->rt == Z_BASIS)
     {
         /* NOTE: this algorithm should *not* be changed */
