@@ -6,13 +6,13 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include "fmpz_mat.h"
 
-void
-fmpz_mat_det_bound(fmpz_t bound, const fmpz_mat_t A)
+static void
+fmpz_mat_det_bound_inner(fmpz_t bound, const fmpz_mat_t A, int zero_cols)
 {
     fmpz_t p, s, t;
     slong i, j;
@@ -33,7 +33,8 @@ fmpz_mat_det_bound(fmpz_t bound, const fmpz_mat_t A)
         if (!fmpz_is_zero(t))
             fmpz_add_ui(s, s, UWORD(1));
 
-        fmpz_mul(p, p, s);
+        if (zero_cols || !fmpz_is_zero(s))
+            fmpz_mul(p, p, s);
     }
 
     fmpz_set(bound, p);
@@ -41,3 +42,15 @@ fmpz_mat_det_bound(fmpz_t bound, const fmpz_mat_t A)
     fmpz_clear(s);
     fmpz_clear(t);
 }
+
+void
+fmpz_mat_det_bound(fmpz_t bound, const fmpz_mat_t A)
+{
+    fmpz_mat_det_bound_inner(bound, A, 1);
+}
+
+void
+fmpz_mat_det_bound_nonzero(fmpz_t bound, const fmpz_mat_t A)
+{
+    fmpz_mat_det_bound_inner(bound, A, 0);
+}
