@@ -7,7 +7,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <stdlib.h>
@@ -19,17 +19,14 @@ void _fmpz_mod_poly_div_basecase(fmpz *Q, fmpz *R,
     const fmpz_t invB, const fmpz_t p)
 {
     const slong alloc = (R == NULL) ? lenA : 0;
-    slong i, lenR = lenB - 1, iQ;
+    slong lenR = lenB - 1, iQ;
     TMP_INIT;
 	
 	TMP_START;
 	
     if (alloc)
-    {
-        R = (fmpz *) TMP_ALLOC(alloc*sizeof(fmpz));
-		for (i = 0; i < alloc; i++)
-		   fmpz_init(R + i);
-    }
+        FMPZ_VEC_TMP_INIT(R, alloc);
+
 	if (R != A)
         _fmpz_vec_set(R + lenR, A + lenR, lenA - lenR);
 
@@ -59,16 +56,13 @@ void _fmpz_mod_poly_div_basecase(fmpz *Q, fmpz *R,
     }
 
     if (alloc)
-	{
-        for (i = 0; i < alloc; i++)
-		    fmpz_clear(R + i);
-	}
+        FMPZ_VEC_TMP_CLEAR(R, alloc);
 	
 	TMP_END;
 }
 
-void fmpz_mod_poly_div_basecase(fmpz_mod_poly_t Q, 
-    const fmpz_mod_poly_t A, const fmpz_mod_poly_t B)
+void fmpz_mod_poly_div_basecase(fmpz_mod_poly_t Q, const fmpz_mod_poly_t A,
+                             const fmpz_mod_poly_t B, const fmpz_mod_ctx_t ctx)
 {
     const slong lenA = A->length, lenB = B->length, lenQ = lenA - lenB + 1;
     fmpz *q;
@@ -76,11 +70,12 @@ void fmpz_mod_poly_div_basecase(fmpz_mod_poly_t Q,
 
     if (lenB == 0)
     {
-        if (fmpz_is_one(fmpz_mod_poly_modulus(B)))
+        if (fmpz_is_one(fmpz_mod_ctx_modulus(ctx)))
         {
-            fmpz_mod_poly_set(Q, A);
+            fmpz_mod_poly_set(Q, A, ctx);
             return;
-        } else
+        }
+        else
         {
             flint_printf("Exception (fmpz_mod_poly_div_basecase). Division by zero.\n");
             flint_abort();
@@ -89,12 +84,12 @@ void fmpz_mod_poly_div_basecase(fmpz_mod_poly_t Q,
 
     if (lenA < lenB)
     {
-        fmpz_mod_poly_zero(Q);
+        fmpz_mod_poly_zero(Q, ctx);
         return;
     }
 
     fmpz_init(invB);
-    fmpz_invmod(invB, B->coeffs + (lenB - 1), &(B->p));
+    fmpz_invmod(invB, B->coeffs + (lenB - 1), fmpz_mod_ctx_modulus(ctx));
 
     if (Q == A || Q == B)
     {
@@ -102,12 +97,12 @@ void fmpz_mod_poly_div_basecase(fmpz_mod_poly_t Q,
     }
     else
     {
-        fmpz_mod_poly_fit_length(Q, lenQ);
+        fmpz_mod_poly_fit_length(Q, lenQ, ctx);
         q = Q->coeffs;
     }
 
     _fmpz_mod_poly_div_basecase(q, NULL, A->coeffs, lenA,
-                                         B->coeffs, lenB, invB, &(B->p));
+                             B->coeffs, lenB, invB, fmpz_mod_ctx_modulus(ctx));
 
     if (Q == A || Q == B)
     {
