@@ -7,7 +7,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <stdlib.h>
@@ -18,7 +18,7 @@ void _fmpz_mod_poly_divrem_basecase(fmpz *Q, fmpz *R,
     const fmpz *A, slong lenA, const fmpz *B, slong lenB, 
     const fmpz_t invB, const fmpz_t p)
 {
-    slong i, iQ, iR;
+    slong iQ, iR;
     fmpz * W;
     TMP_INIT;
 	
@@ -26,14 +26,14 @@ void _fmpz_mod_poly_divrem_basecase(fmpz *Q, fmpz *R,
 	
     if (R != A)
     {
-        W = (fmpz *) TMP_ALLOC(lenA*sizeof(fmpz));
-		
-		for (i = 0; i < lenA; i++)
-		   fmpz_init(W + i);
-		   
+        /* cannot use R as it might not have enough space */
+        FMPZ_VEC_TMP_INIT(W, lenA);
         _fmpz_vec_set(W, A, lenA);
-    } else
+    }
+    else
+    {
        W = R;
+    }
 
     for (iQ = lenA - lenB, iR = lenA - 1; iQ >= 0; iQ--, iR--)
     {
@@ -56,18 +56,15 @@ void _fmpz_mod_poly_divrem_basecase(fmpz *Q, fmpz *R,
 	
     if (R != A)
     {
-       for (i = 0; i < lenB - 1; i++)
-	      fmpz_swap(R + i, W + i);
-	   
-	   for (i = 0; i < lenA; i++)
-	      fmpz_clear(W + i);
+        _fmpz_vec_swap(R, W, lenB - 1);
+        FMPZ_VEC_TMP_CLEAR(W, lenA);
     }
 	
 	TMP_END;
 }
 
 void fmpz_mod_poly_divrem_basecase(fmpz_mod_poly_t Q, fmpz_mod_poly_t R, 
-    const fmpz_mod_poly_t A, const fmpz_mod_poly_t B)
+    const fmpz_mod_poly_t A, const fmpz_mod_poly_t B, const fmpz_mod_ctx_t ctx)
 {
     const slong lenA = A->length, lenB = B->length, lenQ = lenA - lenB + 1;
     fmpz *q, *r;
@@ -75,12 +72,13 @@ void fmpz_mod_poly_divrem_basecase(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
 
     if (lenB == 0)
     {
-        if (fmpz_is_one(fmpz_mod_poly_modulus(B)))
+        if (fmpz_is_one(fmpz_mod_ctx_modulus(ctx)))
         {
-            fmpz_mod_poly_set(Q, A);
-            fmpz_mod_poly_zero(R);
+            fmpz_mod_poly_set(Q, A, ctx);
+            fmpz_mod_poly_zero(R, ctx);
             return;
-        } else
+        }
+        else
         {
             flint_printf("Exception (fmpz_mod_poly_divrem_basecase). Division by zero.\n");
             flint_abort();
@@ -89,13 +87,13 @@ void fmpz_mod_poly_divrem_basecase(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
 
     if (lenA < lenB)
     {
-        fmpz_mod_poly_set(R, A);
-        fmpz_mod_poly_zero(Q);
+        fmpz_mod_poly_set(R, A, ctx);
+        fmpz_mod_poly_zero(Q, ctx);
         return;
     }
 
     fmpz_init(invB);
-    fmpz_invmod(invB, B->coeffs + (lenB - 1), &(B->p));
+    fmpz_invmod(invB, B->coeffs + (lenB - 1), fmpz_mod_ctx_modulus(ctx));
 
     if (Q == A || Q == B)
     {
@@ -103,7 +101,7 @@ void fmpz_mod_poly_divrem_basecase(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
     }
     else
     {
-        fmpz_mod_poly_fit_length(Q, lenQ);
+        fmpz_mod_poly_fit_length(Q, lenQ, ctx);
         q = Q->coeffs;
     }
     if (R == B)
@@ -112,12 +110,12 @@ void fmpz_mod_poly_divrem_basecase(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
     }
     else
     {
-        fmpz_mod_poly_fit_length(R, lenB - 1);
+        fmpz_mod_poly_fit_length(R, lenB - 1, ctx);
         r = R->coeffs;
     }
 
     _fmpz_mod_poly_divrem_basecase(q, r, A->coeffs, lenA,
-                                         B->coeffs, lenB, invB, &(B->p));
+                             B->coeffs, lenB, invB, fmpz_mod_ctx_modulus(ctx));
 
     if (Q == A || Q == B)
     {
