@@ -7,7 +7,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <stdlib.h>
@@ -122,7 +122,8 @@ void _fmpz_mod_poly_divrem_divconquer(fmpz *Q, fmpz *R,
 
 void
 fmpz_mod_poly_divrem_divconquer(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
-    const fmpz_mod_poly_t A, const fmpz_mod_poly_t B)
+                            const fmpz_mod_poly_t A, const fmpz_mod_poly_t B,
+                                                      const fmpz_mod_ctx_t ctx)
 {
     const slong lenA = A->length;
     const slong lenB = B->length;
@@ -133,12 +134,13 @@ fmpz_mod_poly_divrem_divconquer(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
 
     if (lenB == 0)
     {
-        if (fmpz_is_one(fmpz_mod_poly_modulus(B)))
+        if (fmpz_is_one(fmpz_mod_ctx_modulus(ctx)))
         {
-            fmpz_mod_poly_set(Q, A);
-            fmpz_mod_poly_zero(R);
+            fmpz_mod_poly_set(Q, A, ctx);
+            fmpz_mod_poly_zero(R, ctx);
             return;
-        } else
+        }
+        else
         {
             flint_printf("Exception (fmpz_mod_poly_div_basecase). Division by zero.\n");
             flint_abort();
@@ -147,19 +149,19 @@ fmpz_mod_poly_divrem_divconquer(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
 
     if (lenA < lenB)
     {
-        fmpz_mod_poly_set(R, A);
-        fmpz_mod_poly_zero(Q);
+        fmpz_mod_poly_set(R, A, ctx);
+        fmpz_mod_poly_zero(Q, ctx);
         return;
     }
 
 	if (B->length < 8)
 	{
-        fmpz_mod_poly_divrem_basecase(Q, R, A, B);
+        fmpz_mod_poly_divrem_basecase(Q, R, A, B, ctx);
         return;
     }
 	
     fmpz_init(invB);
-    fmpz_invmod(invB, fmpz_mod_poly_lead(B), &(B->p));
+    fmpz_invmod(invB, fmpz_mod_poly_lead(B, ctx), fmpz_mod_ctx_modulus(ctx));
 
     if (Q == A || Q == B)
     {
@@ -167,7 +169,7 @@ fmpz_mod_poly_divrem_divconquer(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
     }
     else
     {
-        fmpz_mod_poly_fit_length(Q, lenQ);
+        fmpz_mod_poly_fit_length(Q, lenQ, ctx);
         q = Q->coeffs;
     }
 
@@ -177,12 +179,12 @@ fmpz_mod_poly_divrem_divconquer(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
     }
     else
     {
-        fmpz_mod_poly_fit_length(R, lenB - 1);
+        fmpz_mod_poly_fit_length(R, lenB - 1, ctx);
         r = R->coeffs;
     }
 
     _fmpz_mod_poly_divrem_divconquer(q, r, A->coeffs, lenA, 
-                                           B->coeffs, lenB, invB, &(B->p));
+                             B->coeffs, lenB, invB, fmpz_mod_ctx_modulus(ctx));
 
     if (Q == A || Q == B)
     {
