@@ -6,7 +6,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #undef ulong
@@ -45,7 +45,7 @@ void _fmpz_mod_poly_divrem_newton_n_preinv (fmpz* Q, fmpz* R, const fmpz* A,
 
 void fmpz_mod_poly_divrem_newton_n_preinv(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
                               const fmpz_mod_poly_t A, const fmpz_mod_poly_t B,
-                              const fmpz_mod_poly_t Binv)
+                         const fmpz_mod_poly_t Binv, const fmpz_mod_ctx_t ctx)
 {
     const slong lenA = A->length, lenB = B->length, lenBinv= Binv->length,
                        lenQ = lenA - lenB + 1;
@@ -53,12 +53,13 @@ void fmpz_mod_poly_divrem_newton_n_preinv(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
 
     if (lenB == 0)
     {
-        if (fmpz_is_one(fmpz_mod_poly_modulus(B)))
+        if (fmpz_is_one(fmpz_mod_ctx_modulus(ctx)))
         {
-            fmpz_mod_poly_set(Q, A);
-            fmpz_mod_poly_zero(R);
+            fmpz_mod_poly_set(Q, A, ctx);
+            fmpz_mod_poly_zero(R, ctx);
             return;
-        } else
+        }
+        else
         {
             flint_printf("Exception (fmpz_mod_poly_divrem_newton_n_preinv)."
                          " Division by zero.\n");
@@ -68,14 +69,15 @@ void fmpz_mod_poly_divrem_newton_n_preinv(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
 
     if (lenA < lenB)
     {
-        fmpz_mod_poly_set(R, A);
-        fmpz_mod_poly_zero(Q);
+        fmpz_mod_poly_set(R, A, ctx);
+        fmpz_mod_poly_zero(Q, ctx);
         return;
     }
 
     if (lenA > 2 * lenB - 2)
     {
-        flint_printf ("Exception (fmpz_mod_poly_divrem_newton_n_preinv).\n");
+        flint_printf("Exception (fmpz_mod_poly_divrem_newton_n_preinv).\n");
+        flint_abort();
     }
 
     if (Q == A || Q == B || Q == Binv)
@@ -84,7 +86,7 @@ void fmpz_mod_poly_divrem_newton_n_preinv(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
     }
     else
     {
-        fmpz_mod_poly_fit_length(Q, lenQ);
+        fmpz_mod_poly_fit_length(Q, lenQ, ctx);
         q = Q->coeffs;
     }
     if (R == A || R == B || R == Binv)
@@ -93,13 +95,13 @@ void fmpz_mod_poly_divrem_newton_n_preinv(fmpz_mod_poly_t Q, fmpz_mod_poly_t R,
     }
     else
     {
-        fmpz_mod_poly_fit_length(R, lenB - 1);
+        fmpz_mod_poly_fit_length(R, lenB - 1, ctx);
         r = R->coeffs;
     }
 
     _fmpz_mod_poly_divrem_newton_n_preinv (q, r, A->coeffs, lenA,
                                            B->coeffs, lenB, Binv->coeffs,
-                                           lenBinv, &(B->p));
+                                           lenBinv, fmpz_mod_ctx_modulus(ctx));
 
     if (Q == A || Q == B || Q == Binv)
     {
