@@ -6,7 +6,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <stdio.h>
@@ -49,8 +49,10 @@ int _fmpz_mod_poly_fprint(FILE * file, const fmpz *poly, slong len,
     return r;
 }
 
-int fmpz_mod_poly_fprint(FILE * file, const fmpz_mod_poly_t poly)
+int fmpz_mod_poly_fprint(FILE * file, const fmpz_mod_poly_t poly,
+                                                      const fmpz_mod_ctx_t ctx)
 {
-    return _fmpz_mod_poly_fprint(file, poly->coeffs, poly->length, &(poly->p));
+   return _fmpz_mod_poly_fprint(file, poly->coeffs, poly->length,
+                                                    fmpz_mod_ctx_modulus(ctx));
 }
 
