@@ -7,7 +7,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <stdlib.h>
@@ -46,7 +46,8 @@ void _fmpz_mod_poly_mulmod(fmpz * res, const fmpz * poly1, slong len1,
 
 void
 fmpz_mod_poly_mulmod(fmpz_mod_poly_t res, const fmpz_mod_poly_t poly1,
-               const fmpz_mod_poly_t poly2, const fmpz_mod_poly_t f)
+               const fmpz_mod_poly_t poly2, const fmpz_mod_poly_t f,
+                                                      const fmpz_mod_ctx_t ctx)
 {
     slong len1, len2, lenf;
     fmpz * fcoeffs;
@@ -63,7 +64,7 @@ fmpz_mod_poly_mulmod(fmpz_mod_poly_t res, const fmpz_mod_poly_t poly1,
 
     if (lenf == 1 || len1 == 0 || len2 == 0)
     {
-        fmpz_mod_poly_zero(res);
+        fmpz_mod_poly_zero(res, ctx);
         return;
     }
 
@@ -75,13 +76,13 @@ fmpz_mod_poly_mulmod(fmpz_mod_poly_t res, const fmpz_mod_poly_t poly1,
             _fmpz_vec_set(fcoeffs, f->coeffs, lenf);
         }
         else
+        {
             fcoeffs = f->coeffs;
+        }
 
-        fmpz_mod_poly_fit_length(res, len1 + len2 - 1);
+        fmpz_mod_poly_fit_length(res, len1 + len2 - 1, ctx);
         _fmpz_mod_poly_mulmod(res->coeffs, poly1->coeffs, len1,
-                              poly2->coeffs, len2,
-                              fcoeffs, lenf,
-                              &res->p);
+                poly2->coeffs, len2, fcoeffs, lenf, fmpz_mod_ctx_modulus(ctx));
         if (f == res)
             _fmpz_vec_clear(fcoeffs, lenf);
 
@@ -90,6 +91,6 @@ fmpz_mod_poly_mulmod(fmpz_mod_poly_t res, const fmpz_mod_poly_t poly1,
     }
     else
     {
-        fmpz_mod_poly_mul(res, poly1, poly2);
+        fmpz_mod_poly_mul(res, poly1, poly2, ctx);
     }
 }
